@@ -610,8 +610,9 @@ int afp_setforkparams(AFPObj *obj, char *ibuf, size_t ibuflen, char *rbuf _U_,
     }
 
     if (movecwd(vol, dir) != 0) {
-        LOG(log_error, logtype_afpd, "%s: bad fork directory", dir->d_fullpath);
-        return AFPERR_MISC;
+        LOG(log_error, logtype_afpd, "%s: bad fork directory",
+            dir->d_fullpath ? cfrombstr(dir->d_fullpath) : "(null)");
+        return afp_errno;
     }
 
     if (ofork->of_vol->v_flags & AFPVOL_RO) {
@@ -853,15 +854,15 @@ int afp_bytelock_ext(AFPObj *obj, char *ibuf, size_t ibuflen, char *rbuf,
 #undef UNLOCKBIT
 
 /*!
- * Read *rbuflen bytes from fork at offset
+ * @brief Read *rbuflen bytes from fork at offset
  *
- * @param ofork    (r)  fork handle
- * @param eid      (r)  data fork or resource fork entry id
- * @param offset   (r)  offset
- * @param rbuf     (r)  data buffer
- * @param rbuflen  (rw) in: number of bytes to read, out: bytes read
+ * @param[in] ofork        fork handle
+ * @param[in] eid          data fork or resource fork entry id
+ * @param[in] offset       offset
+ * @param[in] rbuf         data buffer
+ * @param[in,out] rbuflen  in: number of bytes to read, out: bytes read
  *
- * @return         AFP status code
+ * @returns         AFP status code
  */
 static int read_file(const struct ofork *ofork, int eid, off_t offset,
                      char *rbuf, size_t *rbuflen)
@@ -1158,11 +1159,11 @@ int afp_flushfork(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
     return AFP_OK;
 }
 
-/*
-  FIXME
+/*!
+  @bug
   There is a lot to tell about fsync, fdatasync, F_FULLFSYNC.
   fsync(2) on OSX is implemented differently than on other platforms.
-  see: http://mirror.linux.org.au/pub/linux.conf.au/2007/video/talks/278.pdf.
+  @sa http://mirror.linux.org.au/pub/linux.conf.au/2007/video/talks/278.pdf
 */
 int afp_syncfork(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
                  char *rbuf _U_, size_t *rbuflen)
