@@ -9,14 +9,16 @@ struct atport {
     int			ap_fd;
     struct atport	*ap_next;
     struct interface	*ap_iface;
-    u_char		ap_port;
-    int			(*ap_packet)(struct atport *ap, struct sockaddr_at *from, char *data, int len);
+    unsigned char		ap_port;
+    int	(*ap_packet)(struct atport *ap, struct sockaddr_at *from, char *data,
+                     int len);
 };
 
 struct atserv {
     char	*as_name;
-    u_char	as_port;		/* Used as a fall back */
-    int		(*as_packet)(struct atport *ap, struct sockaddr_at *from, char *data, int len);
+    unsigned char	as_port;		/* Used as a fall back */
+    int	(*as_packet)(struct atport *ap, struct sockaddr_at *from, char *data,
+                     int len);
 };
 
 #endif
