@@ -4,8 +4,7 @@
 #include <atalk/cnid_private.h>
 #include <atalk/uuid.h>
 
-/* CNID set overflowed */
-#define CNID_SQLITE_FLAG_DEPLETED (1 << 0)
+#define CNID_SQLITE_FLAG_DEPLETED (1 << 0) /*!< CNID set overflowed */
 
 typedef struct CNID_sqlite_private {
     struct vol *vol;
@@ -20,6 +19,7 @@ typedef struct CNID_sqlite_private {
     sqlite3_stmt *cnid_resolve_stmt;
     sqlite3_stmt *cnid_delete_stmt;
     sqlite3_stmt *cnid_getstamp_stmt;
+    sqlite3_stmt *cnid_find_stmt;
 } CNID_sqlite_private;
 
 #endif
