@@ -5,6 +5,7 @@
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include <signal.h>
 
@@ -14,9 +15,8 @@
 #endif
 
 #if !defined(HAVE_PSELECT) || defined(__OpenBSD__)
-extern int pselect(int, fd_set *restrict, fd_set *restrict,
-                   fd_set *restrict, const struct timespec *restrict,
-                   const sigset_t *restrict);
+extern int pselect(int, fd_set *, fd_set *, fd_set *, const struct timespec *,
+                   const sigset_t *);
 #endif
 
 #ifndef HAVE_STRNLEN
@@ -37,4 +37,11 @@ extern size_t strlcat(char *, const char *, size_t);
 extern int vasprintf(char **ret, const char *fmt, va_list ap);
 #endif
 
+/* Secure memory clearing - prefer memset_explicit (C23) over explicit_bzero */
+#if !defined(HAVE_MEMSET_EXPLICIT) && !defined(HAVE_EXPLICIT_BZERO)
+#include <stddef.h>
+extern void explicit_bzero(void *s, size_t n);
+#elif defined(HAVE_MEMSET_EXPLICIT) && !defined(HAVE_EXPLICIT_BZERO)
+#include <string.h>
+#define explicit_bzero(s, n) memset_explicit((s), 0, (n))
 #endif
