@@ -21,7 +21,8 @@
  *	netatalk@itd.umich.edu
  */
 
-/* 
+/*!
+ * @file
  * Our own memory maintenance for atp
 */
 
@@ -32,6 +33,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
+#include <unistd.h>
 
 #include <sys/types.h>
 #include <sys/time.h>
@@ -41,9 +43,13 @@
 #include <atalk/atp.h>
 #include "atp_internals.h"
 
+#ifdef EBUG
+#include <stdio.h>
+#endif /* EBUG */
+
 #define			N_MORE_BUFS		10
 
-static struct atpbuf 	*free_list = NULL;	/* free buffers */
+static struct atpbuf 	*free_list = NULL;	/*!< free buffers */
 
 #ifdef EBUG
 static int		numbufs = 0;
@@ -60,19 +66,21 @@ static int more_bufs(void)
 
     /* get the whole chunk in one malloc call
     */
-    if (( mem = malloc( N_MORE_BUFS * sizeof( struct atpbuf ))) == NULL ) {
-	errno = ENOBUFS;
-	return -1;
+    if ((mem = malloc(N_MORE_BUFS * sizeof(struct atpbuf))) == NULL) {
+        errno = ENOBUFS;
+        return -1;
     }
+
     /* now split into separate bufs
     */
     bp = free_list = (struct atpbuf *) mem;
-    for ( i = 1; i < N_MORE_BUFS; ++i ) {
-	bp->atpbuf_next = (struct atpbuf *) ( mem += sizeof( struct atpbuf ));
-	bp = bp->atpbuf_next;
-    }
-    bp->atpbuf_next = NULL;
 
+    for (i = 1; i < N_MORE_BUFS; ++i) {
+        bp->atpbuf_next = (struct atpbuf *)(mem += sizeof(struct atpbuf));
+        bp = bp->atpbuf_next;
+    }
+
+    bp->atpbuf_next = NULL;
     return 0;
 }
 
@@ -80,37 +88,42 @@ static int more_bufs(void)
 #ifdef EBUG
 void atp_print_bufuse(ATP ah, char *s)
 {
-    struct atpbuf	*bp;
-    int			i, sentcount, incount, respcount;
-
+    struct atpbuf *bp;
+    int i;
+    int sentcount;
+    int incount;
+    int respcount;
     sentcount = 0;
-    for ( bp = ah->atph_sent; bp != NULL; bp = bp->atpbuf_next ) {
-	++sentcount;
-	for ( i = 0; i < 8; ++i ) {
-	    if ( bp->atpbuf_info.atpbuf_xo.atpxo_packet[ i ] != NULL ) {
-		++sentcount;
-	    }
-	}
+
+    for (bp = ah->atph_sent; bp != NULL; bp = bp->atpbuf_next) {
+        ++sentcount;
+
+        for (i = 0; i < 8; ++i) {
+            if (bp->atpbuf_info.atpbuf_xo.atpxo_packet[i] != NULL) {
+                ++sentcount;
+            }
+        }
     }
 
-    if ( ah->atph_reqpkt != NULL ) {
-	++sentcount;
+    if (ah->atph_reqpkt != NULL) {
+        ++sentcount;
     }
 
-
     incount = 0;
-    for ( bp = ah->atph_queue; bp != NULL; bp = bp->atpbuf_next, ++incount );
+
+    for (bp = ah->atph_queue; bp != NULL; bp = bp->atpbuf_next, ++incount);
 
     respcount = 0;
-    for ( i = 0; i < 8; ++i ) {
-        if ( ah->atph_resppkt[ i ] != NULL ) {
-	    ++respcount;
-	}
+
+    for (i = 0; i < 8; ++i) {
+        if (ah->atph_resppkt[i] != NULL) {
+            ++respcount;
+        }
     }
 
-    printf( "<%d> %s: bufs total %d  sent %d  incoming %d  req %d  resp %d\n",
-	getpid(), s, numbufs, sentcount, incount,
-	( ah->atph_reqpkt != NULL ) ? 1: 0, respcount );
+    printf("<%d> %s: bufs total %d  sent %d  incoming %d  req %d  resp %d\n",
+           getpid(), s, numbufs, sentcount, incount,
+           (ah->atph_reqpkt != NULL) ? 1 : 0, respcount);
 }
 #endif /* EBUG */
 
@@ -119,7 +132,9 @@ struct atpbuf *atp_alloc_buf(void)
 {
     struct atpbuf *bp;
 
-    if ( free_list == NULL && more_bufs() ) return NULL;
+    if (free_list == NULL && more_bufs()) {
+        return NULL;
+    }
 
     bp = free_list;
     free_list = free_list->atpbuf_next;
@@ -132,9 +147,10 @@ struct atpbuf *atp_alloc_buf(void)
 
 int atp_free_buf(struct atpbuf *bp)
 {
-    if ( bp == NULL ) {
-	return -1;
+    if (bp == NULL) {
+        return -1;
     }
+
     bp->atpbuf_next = free_list;
     free_list = bp;
 #ifdef EBUG
