@@ -8,8 +8,6 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#ifdef CNID_BACKEND_DBD
-
 #include <arpa/inet.h>
 #include <arpa/inet.h>
 #include <errno.h>
@@ -41,19 +39,18 @@
 #define SOL_TCP IPPROTO_TCP
 #endif /* ! SOL_TCP */
 
-/* Wait MAX_DELAY seconds before a request to the CNID server times out */
+/*! Wait MAX_DELAY seconds before a request to the CNID server times out */
 #define MAX_DELAY 20
 #define ONE_DELAY 5
 
 static void RQST_RESET(struct cnid_dbd_rqst  *r)
 {
-    memset(r, 0, sizeof(struct cnid_dbd_rqst ));
+    memset(r, 0, sizeof(struct cnid_dbd_rqst));
 }
 
 static void delay(int sec)
 {
     struct timeval tv;
-
     tv.tv_usec = 0;
     tv.tv_sec  = sec;
     select(0, NULL, NULL, NULL, &tv);
@@ -65,11 +62,10 @@ static int tsock_getfd(const char *host, const char *port)
     int attr;
     int err;
     struct addrinfo hints, *servinfo, *p;
-    int optval;
+    int optval = ECONNREFUSED;
     socklen_t optlen = sizeof(optval);
-
     /* Prepare hint for getaddrinfo */
-    memset(&hints, 0, sizeof hints);
+    memset(&hints, 0, sizeof(hints));
     hints.ai_family = AF_UNSPEC;
     hints.ai_socktype = SOCK_STREAM;
 #ifdef AI_NUMERICSERV
@@ -77,7 +73,8 @@ static int tsock_getfd(const char *host, const char *port)
 #endif
 
     if ((err = getaddrinfo(host, port, &hints, &servinfo)) != 0) {
-        LOG(log_error, logtype_default, "tsock_getfd: getaddrinfo: CNID server %s:%s : %s\n",
+        LOG(log_error, logtype_default,
+            "tsock_getfd: getaddrinfo: CNID server %s:%s : %s\n",
             host, port, gai_strerror(err));
         return -1;
     }
@@ -91,6 +88,7 @@ static int tsock_getfd(const char *host, const char *port)
         }
 
         attr = 1;
+
         if (setsockopt(sock, SOL_TCP, TCP_NODELAY, &attr, sizeof(attr)) == -1) {
             LOG(log_error, logtype_cnid, "getfd: set TCP_NODELAY CNID server %s: %s",
                 host, strerror(errno));
@@ -123,6 +121,7 @@ static int tsock_getfd(const char *host, const char *port)
                     sock = -1;
                     continue;
                 }
+
                 if (err == -1) {
                     /* select failed */
                     LOG(log_error, logtype_cnid, "getfd: select failed for CNID server %s",
@@ -132,7 +131,7 @@ static int tsock_getfd(const char *host, const char *port)
                     continue;
                 }
 
-                if ( ! FD_ISSET(sock, &wfds)) {
+                if (! FD_ISSET(sock, &wfds)) {
                     /* give up */
                     LOG(log_error, logtype_cnid, "getfd: socket not ready connecting to %s",
                         host);
@@ -141,7 +140,8 @@ static int tsock_getfd(const char *host, const char *port)
                     continue;
                 }
 
-                if ((err = getsockopt(sock, SOL_SOCKET, SO_ERROR, &optval, &optlen)) != 0 || optval != 0) {
+                if ((err = getsockopt(sock, SOL_SOCKET, SO_ERROR, &optval, &optlen)) != 0
+                        || optval != 0) {
                     if (err != 0) {
                         /* somethings very wrong */
                         LOG(log_error, logtype_cnid, "getfd: getsockopt error with CNID server %s: %s",
@@ -151,6 +151,7 @@ static int tsock_getfd(const char *host, const char *port)
                         LOG(log_error, logtype_cnid, "getfd: getsockopt says: %s",
                             strerror(errno));
                     }
+
                     close(sock);
                     sock = -1;
                     continue;
@@ -172,23 +173,24 @@ static int tsock_getfd(const char *host, const char *port)
 
     if (p == NULL) {
         errno = optval;
-        LOG(log_error, logtype_cnid, "tsock_getfd: no suitable network config from CNID server (%s:%s): %s",
+        LOG(log_error, logtype_cnid,
+            "tsock_getfd: no suitable network config from CNID server (%s:%s): %s",
             host, port, strerror(errno));
         return -1;
     }
 
-    return(sock);
+    return sock;
 }
 
 /*!
- * Write "towrite" bytes using writev on non-blocking fd
+ * @brief Write "towrite" bytes using writev on non-blocking fd
  *
  * Every short write is considered an error, transmit can handle that.
  *
- * @param fd      (r) socket fd which must be non-blocking
- * @param iov     (r) iovec for writev
- * @param towrite (r) number of bytes in all iovec elements
- * @param vecs    (r) number of iovecs in array
+ * @param[in] fd       socket fd which must be non-blocking
+ * @param[in] iov      iovec for writev
+ * @param[in] towrite  number of bytes in all iovec elements
+ * @param[in] vecs     number of iovecs in array
  *
  * @returns "towrite" bytes written or -1 on error
  */
@@ -199,28 +201,33 @@ static int write_vec(int fd, struct iovec *iov, ssize_t towrite, int vecs)
     int sleepsecs;
 
     while (1) {
-        if (((len = writev(fd, iov, vecs)) == -1 && errno == EINTR))
+        if ((len = writev(fd, iov, vecs)) == -1 && errno == EINTR) {
             continue;
+        }
 
         if ((! slept) && len == -1 && errno == EAGAIN) {
             sleepsecs = 2;
+
             while ((sleepsecs = sleep(sleepsecs)));
+
             slept = 1;
             continue;
         }
 
-        if (len == towrite) /* wrote everything out */
+        if (len == towrite) { /* wrote everything out */
             break;
+        }
 
-        if (len == -1)
+        if (len == -1) {
             LOG(log_error, logtype_cnid, "write_vec: %s", strerror(errno));
-        else
+        } else {
             LOG(log_error, logtype_cnid, "write_vec: short write: %d", len);
+        }
+
         return len;
     }
 
     LOG(log_maxdebug, logtype_cnid, "write_vec: wrote %d bytes", len);
-
     return len;
 }
 
@@ -233,28 +240,24 @@ static int init_tsock(CNID_bdb_private *db)
     struct iovec iov[DBD_NUM_OPEN_ARGS + 1] = {{0}};
     struct vol *vol = db->vol;
     ssize_t iovlen;
-
     LOG(log_debug, logtype_cnid, "connecting to CNID server: %s:%s",
         vol->v_cnidserver, vol->v_cnidport);
 
-    if ((fd = tsock_getfd(vol->v_cnidserver, vol->v_cnidport)) < 0)
+    if ((fd = tsock_getfd(vol->v_cnidserver, vol->v_cnidport)) < 0) {
         return -1;
+    }
 
     LOG(log_debug, logtype_cnid, "connecting volume '%s', path: %s, user: %s",
-        vol->v_configname, vol->v_path, vol->v_obj->username[0] ? vol->v_obj->username : "-");
-
+        vol->v_configname, vol->v_path,
+        vol->v_obj->username[0] ? vol->v_obj->username : "-");
     iovecs = 1 + DBD_NUM_OPEN_ARGS - 1;
-
     len[0] = strlen(vol->v_configname) + 1;
     len[1] = strlen(vol->v_path) + 1;
     len[2] = strlen(vol->v_obj->username);
-
     iov[0].iov_base = &len[0];
     iov[0].iov_len  = DBD_NUM_OPEN_ARGS * sizeof(int);
-
     iov[1].iov_base = vol->v_configname;
     iov[1].iov_len  = len[0];
-
     iov[2].iov_base = vol->v_path;
     iov[2].iov_len  = len[1];
 
@@ -268,13 +271,13 @@ static int init_tsock(CNID_bdb_private *db)
     iovlen = iov[0].iov_len + iov[1].iov_len + iov[2].iov_len + iov[3].iov_len;
 
     if (write_vec(fd, iov, iovlen, iovecs) != iovlen) {
-        LOG(log_error, logtype_cnid, "init_tsock: Error/short write: %s", strerror(errno));
+        LOG(log_error, logtype_cnid, "init_tsock: Error/short write: %s",
+            strerror(errno));
         close(fd);
         return -1;
     }
 
     LOG(log_debug, logtype_cnid, "init_tsock: ok");
-
     return fd;
 }
 
@@ -284,7 +287,6 @@ static int send_packet(CNID_bdb_private *db, struct cnid_dbd_rqst *rqst)
     struct iovec iov[2];
     size_t towrite;
     int vecs;
-
     iov[0].iov_base = rqst;
     iov[0].iov_len  = sizeof(struct cnid_dbd_rqst);
     towrite = sizeof(struct cnid_dbd_rqst);
@@ -320,22 +322,26 @@ static int dbd_reply_stamp(struct cnid_dbd_rply *rply)
     switch (rply->result) {
     case CNID_DBD_RES_OK:
         break;
+
     case CNID_DBD_RES_NOTFOUND:
         return -1;
+
     case CNID_DBD_RES_ERR_DB:
     default:
         errno = CNID_ERR_DB;
         return -1;
     }
+
     return 0;
 }
 
-/* ---------------------
- * send a request and get reply
- * assume send is non blocking
- * if no answer after sometime (at least MAX_DELAY secondes) return an error
+/*!
+ * @brief send a request and get reply
+ * @note assume send is non blocking
+ * @note if no answer after sometime (at least MAX_DELAY secondes) return an error
  */
-static int dbd_rpc(CNID_bdb_private *db, struct cnid_dbd_rqst *rqst, struct cnid_dbd_rply *rply)
+static int dbd_rpc(CNID_bdb_private *db, struct cnid_dbd_rqst *rqst,
+                   struct cnid_dbd_rply *rply)
 {
     ssize_t ret;
     char *nametmp;
@@ -344,37 +350,44 @@ static int dbd_rpc(CNID_bdb_private *db, struct cnid_dbd_rqst *rqst, struct cnid
     if (send_packet(db, rqst) < 0) {
         return -1;
     }
+
     len = rply->namelen;
     nametmp = rply->name;
-
     ret = readt(db->fd, rply, sizeof(struct cnid_dbd_rply), 0, ONE_DELAY);
 
     if (ret != sizeof(struct cnid_dbd_rply)) {
-        LOG(log_debug, logtype_cnid, "dbd_rpc: Error reading header from fd (volume %s): %s",
+        LOG(log_debug, logtype_cnid,
+            "dbd_rpc: Error reading header from fd (volume %s): %s",
             db->vol->v_localname, ret == -1 ? strerror(errno) : "closed");
         rply->name = nametmp;
         return -1;
     }
+
     rply->name = nametmp;
+
     if (rply->namelen && rply->namelen > len) {
         LOG(log_error, logtype_cnid,
             "dbd_rpc: Error reading name (volume %s): %s name too long: %d. only wanted %d, garbage?",
             db->vol->v_localname, rply->name, rply->namelen, len);
         return -1;
     }
-    if (rply->namelen && (ret = readt(db->fd, rply->name, rply->namelen, 0, ONE_DELAY)) != (ssize_t)rply->namelen) {
-        LOG(log_error, logtype_cnid, "dbd_rpc: Error reading name from fd (volume %s): %s",
-            db->vol->v_localname, ret == -1?strerror(errno):"closed");
+
+    if (rply->namelen
+            && (ret = readt(db->fd, rply->name, rply->namelen, 0,
+                            ONE_DELAY)) != (ssize_t)rply->namelen) {
+        LOG(log_error, logtype_cnid,
+            "dbd_rpc: Error reading name from fd (volume %s): %s",
+            db->vol->v_localname, ret == -1 ? strerror(errno) : "closed");
         return -1;
     }
 
     LOG(log_maxdebug, logtype_cnid, "dbd_rpc: {done}");
-
     return 0;
 }
 
 /* -------------------- */
-static int transmit(CNID_bdb_private *db, struct cnid_dbd_rqst *rqst, struct cnid_dbd_rply *rply)
+static int transmit(CNID_bdb_private *db, struct cnid_dbd_rqst *rqst,
+                    struct cnid_dbd_rply *rply)
 {
     time_t orig, t;
     int clean = 1; /* no errors so far - to prevent sleep on first try */
@@ -382,21 +395,28 @@ static int transmit(CNID_bdb_private *db, struct cnid_dbd_rqst *rqst, struct cni
     while (1) {
         if (db->fd == -1) {
             LOG(log_maxdebug, logtype_cnid, "transmit: connecting to cnid_dbd ...");
+
             if ((db->fd = init_tsock(db)) < 0) {
                 goto transmit_fail;
             }
+
             if (db->notfirst) {
                 LOG(log_debug7, logtype_cnid, "transmit: reconnected to cnid_dbd");
             } else { /* db->notfirst == 0 */
                 db->notfirst = 1;
             }
-            LOG(log_debug, logtype_cnid, "transmit: attached to '%s'", db->vol->v_localname);
+
+            LOG(log_debug, logtype_cnid, "transmit: attached to '%s'",
+                db->vol->v_localname);
         }
+
         if (!dbd_rpc(db, rqst, rply)) {
             LOG(log_maxdebug, logtype_cnid, "transmit: {done}");
             return 0;
         }
-    transmit_fail:
+
+transmit_fail:
+
         if (db->fd != -1) {
             close(db->fd);
             db->fd = -1; /* FD not valid... will need to reconnect */
@@ -404,16 +424,20 @@ static int transmit(CNID_bdb_private *db, struct cnid_dbd_rqst *rqst, struct cni
 
         if (errno == ECONNREFUSED) { /* errno carefully injected in tsock_getfd */
             /* give up */
-            LOG(log_error, logtype_cnid, "transmit: connection refused (volume %s)", db->vol->v_localname);
+            LOG(log_error, logtype_cnid, "transmit: connection refused (volume %s)",
+                db->vol->v_localname);
             return -1;
         }
 
         if (!clean) { /* don't sleep if just got disconnected by cnid server */
             time(&t);
+
             if (t - orig > MAX_DELAY) {
-                LOG(log_error, logtype_cnid, "transmit: Request to dbd daemon (volume %s) timed out.", db->vol->v_localname);
+                LOG(log_error, logtype_cnid,
+                    "transmit: Request to dbd daemon (volume %s) timed out.", db->vol->v_localname);
                 return -1;
             }
+
             /* sleep a little before retry */
             delay(1);
         } else {
@@ -421,6 +445,7 @@ static int transmit(CNID_bdb_private *db, struct cnid_dbd_rqst *rqst, struct cni
             time(&orig);
         }
     }
+
     return -1;
 }
 
@@ -429,8 +454,9 @@ static struct _cnid_db *cnid_dbd_new(struct vol *vol)
 {
     struct _cnid_db *cdb;
 
-    if ((cdb = (struct _cnid_db *)calloc(1, sizeof(struct _cnid_db))) == NULL)
+    if ((cdb = (struct _cnid_db *)calloc(1, sizeof(struct _cnid_db))) == NULL) {
         return NULL;
+    }
 
     cdb->cnid_db_vol = vol;
     cdb->cnid_db_flags = CNID_FLAG_PERSISTENT | CNID_FLAG_LAZY_INIT;
@@ -456,30 +482,33 @@ struct _cnid_db *cnid_dbd_open(struct cnid_open_args *args)
     struct _cnid_db *cdb = NULL;
 
     if ((cdb = cnid_dbd_new(args->cnid_args_vol)) == NULL) {
-        LOG(log_error, logtype_cnid, "cnid_open: Unable to allocate memory for database");
+        LOG(log_error, logtype_cnid,
+            "cnid_open: Unable to allocate memory for database");
         return NULL;
     }
 
     if ((db = (CNID_bdb_private *)calloc(1, sizeof(CNID_bdb_private))) == NULL) {
-        LOG(log_error, logtype_cnid, "cnid_open: Unable to allocate memory for database");
+        LOG(log_error, logtype_cnid,
+            "cnid_open: Unable to allocate memory for database");
         goto cnid_dbd_open_fail;
     }
 
     cdb->cnid_db_private = db;
-
     db->fd = -1;
     db->vol = args->cnid_args_vol;
-
-    LOG(log_debug, logtype_cnid, "Finished initializing CNID dbd module for volume '%s'",
+    LOG(log_debug, logtype_cnid,
+        "Finished initializing CNID dbd module for volume '%s'",
         args->cnid_args_vol->v_localname);
-
     return cdb;
-
 cnid_dbd_open_fail:
-    if (cdb != NULL)
+
+    if (cdb != NULL) {
         free(cdb);
-    if (db != NULL)
+    }
+
+    if (db != NULL) {
         free(db);
+    }
 
     return NULL;
 }
@@ -495,41 +524,46 @@ void cnid_dbd_close(struct _cnid_db *cdb)
     }
 
     if ((db = cdb->cnid_db_private) != NULL) {
-        LOG(log_debug, logtype_cnid, "closing database connection for volume '%s'", db->vol->v_localname);
+        LOG(log_debug, logtype_cnid, "closing database connection for volume '%s'",
+            db->vol->v_localname);
 
-        if (db->fd >= 0)
+        if (db->fd >= 0) {
             close(db->fd);
+        }
+
         free(db);
     }
 
     free(cdb);
-
     return;
 }
 
-/**
+/*!
  * Get the db stamp
- **/
+ */
 static int cnid_dbd_stamp(CNID_bdb_private *db)
 {
     struct cnid_dbd_rqst rqst_stamp;
     struct cnid_dbd_rply rply_stamp;
     char  stamp[ADEDLEN_PRIVSYN];
-
     dbd_initstamp(&rqst_stamp);
     memset(stamp, 0, ADEDLEN_PRIVSYN);
     rply_stamp.name = stamp;
     rply_stamp.namelen = ADEDLEN_PRIVSYN;
 
-    if (transmit(db, &rqst_stamp, &rply_stamp) < 0)
-        return -1;
-    if (dbd_reply_stamp(&rply_stamp ) < 0)
+    if (transmit(db, &rqst_stamp, &rply_stamp) < 0) {
         return -1;
+    }
 
-    if (db->client_stamp)
+    if (dbd_reply_stamp(&rply_stamp) < 0) {
+        return -1;
+    }
+
+    if (db->client_stamp) {
         memcpy(db->client_stamp, stamp, ADEDLEN_PRIVSYN);
-    memcpy(db->stamp, stamp, ADEDLEN_PRIVSYN);
+    }
 
+    memcpy(db->stamp, stamp, ADEDLEN_PRIVSYN);
     return 0;
 }
 
@@ -539,7 +573,7 @@ cnid_t cnid_dbd_add(struct _cnid_db *cdb, const struct stat *st,
 {
     CNID_bdb_private *db;
     struct cnid_dbd_rqst rqst;
-    struct cnid_dbd_rply rply;
+    struct cnid_dbd_rply rply = { 0 };
     cnid_t id;
 
     if (!cdb || !(db = cdb->cnid_db_private) || !st || !name) {
@@ -562,36 +596,42 @@ cnid_t cnid_dbd_add(struct _cnid_db *cdb, const struct stat *st,
     }
 
     rqst.ino = st->st_ino;
-    rqst.type = S_ISDIR(st->st_mode)?1:0;
+    rqst.type = S_ISDIR(st->st_mode) ? 1 : 0;
     rqst.cnid = hint;
     rqst.did = did;
     rqst.name = name;
     rqst.namelen = len;
-
-    LOG(log_debug, logtype_cnid, "cnid_dbd_add: CNID: %u, name: '%s', dev: 0x%llx, inode: 0x%llx, type: %s",
-        ntohl(did), name, (long long)rqst.dev, (long long)st->st_ino, rqst.type ? "dir" : "file");
-
+    LOG(log_debug, logtype_cnid,
+        "cnid_dbd_add: CNID: %u, name: '%s', dev: 0x%llx, inode: 0x%llx, type: %s",
+        ntohl(did), name, (long long)rqst.dev, (long long)st->st_ino,
+        rqst.type ? "dir" : "file");
     rply.namelen = 0;
+
     if (transmit(db, &rqst, &rply) < 0) {
         errno = CNID_ERR_DB;
         return CNID_INVALID;
     }
 
-    switch(rply.result) {
+    switch (rply.result) {
     case CNID_DBD_RES_OK:
         id = rply.cnid;
         LOG(log_debug, logtype_cnid, "cnid_dbd_add: got CNID: %u", ntohl(id));
         break;
+
     case CNID_DBD_RES_ERR_MAX:
         errno = CNID_ERR_MAX;
         id = CNID_INVALID;
         break;
+
     case CNID_DBD_RES_ERR_DB:
     case CNID_DBD_RES_ERR_DUPLCNID:
         errno = CNID_ERR_DB;
         id = CNID_INVALID;
         break;
+
     default:
+        LOG(log_error, logtype_cnid,
+            "cnid_dbd_add: unexpected result code %d from CNID server", rply.result);
         abort();
     }
 
@@ -599,7 +639,8 @@ cnid_t cnid_dbd_add(struct _cnid_db *cdb, const struct stat *st,
 }
 
 /* ---------------------- */
-cnid_t cnid_dbd_get(struct _cnid_db *cdb, cnid_t did, const char *name, size_t len)
+cnid_t cnid_dbd_get(struct _cnid_db *cdb, cnid_t did, const char *name,
+                    size_t len)
 {
     CNID_bdb_private *db;
     struct cnid_dbd_rqst rqst;
@@ -618,33 +659,38 @@ cnid_t cnid_dbd_get(struct _cnid_db *cdb, cnid_t did, const char *name, size_t l
         return CNID_INVALID;
     }
 
-    LOG(log_debug, logtype_cnid, "cnid_dbd_get: DID: %u, name: '%s'", ntohl(did), name);
-
+    LOG(log_debug, logtype_cnid, "cnid_dbd_get: DID: %u, name: '%s'", ntohl(did),
+        name);
     RQST_RESET(&rqst);
     rqst.op = CNID_DBD_OP_GET;
     rqst.did = did;
     rqst.name = name;
     rqst.namelen = len;
-
     rply.namelen = 0;
+
     if (transmit(db, &rqst, &rply) < 0) {
         errno = CNID_ERR_DB;
         return CNID_INVALID;
     }
 
-    switch(rply.result) {
+    switch (rply.result) {
     case CNID_DBD_RES_OK:
         id = rply.cnid;
         LOG(log_debug, logtype_cnid, "cnid_dbd_get: got CNID: %u", ntohl(id));
         break;
+
     case CNID_DBD_RES_NOTFOUND:
         id = CNID_INVALID;
         break;
+
     case CNID_DBD_RES_ERR_DB:
         id = CNID_INVALID;
         errno = CNID_ERR_DB;
         break;
+
     default:
+        LOG(log_error, logtype_cnid,
+            "cnid_dbd_get: unexpected result code %d from CNID server", rply.result);
         abort();
     }
 
@@ -652,7 +698,8 @@ cnid_t cnid_dbd_get(struct _cnid_db *cdb, cnid_t did, const char *name, size_t l
 }
 
 /* ---------------------- */
-char *cnid_dbd_resolve(struct _cnid_db *cdb, cnid_t *id, void *buffer, size_t len)
+char *cnid_dbd_resolve(struct _cnid_db *cdb, cnid_t *id, void *buffer,
+                       size_t len)
 {
     CNID_bdb_private *db;
     struct cnid_dbd_rqst rqst;
@@ -665,22 +712,23 @@ char *cnid_dbd_resolve(struct _cnid_db *cdb, cnid_t *id, void *buffer, size_t le
         return NULL;
     }
 
-    LOG(log_debug, logtype_cnid, "cnid_dbd_resolve: resolving CNID: %u", ntohl(*id));
-
+    LOG(log_debug, logtype_cnid, "cnid_dbd_resolve: resolving CNID: %u",
+        ntohl(*id));
     /* TODO: We should maybe also check len. At the moment we rely on the caller
        to provide a buffer that is large enough for MAXPATHLEN plus
        CNID_HEADER_LEN plus 1 byte, which is large enough for the maximum that
        can come from the database. */
-
     RQST_RESET(&rqst);
     rqst.op = CNID_DBD_OP_RESOLVE;
     rqst.cnid = *id;
-
     /* Pass buffer to transmit so it can stuff the reply data there */
     rply.name = (char *)buffer;
     rply.namelen = len;
 
     if (transmit(db, &rqst, &rply) < 0) {
+        LOG(log_error, logtype_cnid,
+            "cnid_dbd_resolve: transmit failed for CNID %u: %s",
+            ntohl(*id), strerror(errno));
         errno = CNID_ERR_DB;
         *id = CNID_INVALID;
         return NULL;
@@ -690,27 +738,36 @@ char *cnid_dbd_resolve(struct _cnid_db *cdb, cnid_t *id, void *buffer, size_t le
     case CNID_DBD_RES_OK:
         *id = rply.did;
         name = rply.name + CNID_NAME_OFS;
-        LOG(log_debug, logtype_cnid, "cnid_dbd_resolve: resolved did: %u, name: '%s'", ntohl(*id), name);
+        LOG(log_debug, logtype_cnid, "cnid_dbd_resolve: resolved did: %u, name: '%s'",
+            ntohl(*id), name);
         break;
+
     case CNID_DBD_RES_NOTFOUND:
+        LOG(log_info, logtype_cnid,
+            "cnid_dbd_resolve: CNID %u not found in database (likely deleted)",
+            ntohl(*id));
         *id = CNID_INVALID;
         name = NULL;
         break;
+
     case CNID_DBD_RES_ERR_DB:
         errno = CNID_ERR_DB;
         *id = CNID_INVALID;
         name = NULL;
         break;
+
     default:
+        LOG(log_error, logtype_cnid,
+            "cnid_dbd_resolve: unexpected result code %d from CNID server", rply.result);
         abort();
     }
 
     return name;
 }
 
-/**
+/*!
  * Caller passes buffer where we will store the db stamp
- **/
+ */
 int cnid_dbd_getstamp(struct _cnid_db *cdb, void *buffer, const size_t len)
 {
     CNID_bdb_private *db;
@@ -720,9 +777,9 @@ int cnid_dbd_getstamp(struct _cnid_db *cdb, void *buffer, const size_t len)
         errno = CNID_ERR_PARAM;
         return -1;
     }
+
     db->client_stamp = buffer;
     db->stamp_size = len;
-
     return cnid_dbd_stamp(db);
 }
 
@@ -755,15 +812,15 @@ cnid_t cnid_dbd_lookup(struct _cnid_db *cdb, const struct stat *st, cnid_t did,
     }
 
     rqst.ino = st->st_ino;
-    rqst.type = S_ISDIR(st->st_mode)?1:0;
+    rqst.type = S_ISDIR(st->st_mode) ? 1 : 0;
     rqst.did = did;
     rqst.name = name;
     rqst.namelen = len;
-
-    LOG(log_debug, logtype_cnid, "cnid_dbd_lookup: CNID: %u, name: '%s', inode: 0x%llx, type: %d (0=file, 1=dir)",
+    LOG(log_debug, logtype_cnid,
+        "cnid_dbd_lookup: CNID: %u, name: '%s', inode: 0x%llx, type: %d (0=file, 1=dir)",
         ntohl(did), name, (long long)st->st_ino, rqst.type);
-
     rply.namelen = 0;
+
     if (transmit(db, &rqst, &rply) < 0) {
         errno = CNID_ERR_DB;
         return CNID_INVALID;
@@ -774,14 +831,19 @@ cnid_t cnid_dbd_lookup(struct _cnid_db *cdb, const struct stat *st, cnid_t did,
         id = rply.cnid;
         LOG(log_debug, logtype_cnid, "cnid_dbd_lookup: got CNID: %u", ntohl(id));
         break;
+
     case CNID_DBD_RES_NOTFOUND:
         id = CNID_INVALID;
         break;
+
     case CNID_DBD_RES_ERR_DB:
         errno = CNID_ERR_DB;
         id = CNID_INVALID;
         break;
+
     default:
+        LOG(log_error, logtype_cnid,
+            "cnid_dbd_lookup: unexpected result code %d from CNID server", rply.result);
         abort();
     }
 
@@ -789,7 +851,8 @@ cnid_t cnid_dbd_lookup(struct _cnid_db *cdb, const struct stat *st, cnid_t did,
 }
 
 /* ---------------------- */
-int cnid_dbd_find(struct _cnid_db *cdb, const char *name, size_t namelen, void *buffer, size_t buflen)
+int cnid_dbd_find(struct _cnid_db *cdb, const char *name, size_t namelen,
+                  void *buffer, size_t buflen)
 {
     CNID_bdb_private *db;
     struct cnid_dbd_rqst rqst;
@@ -809,13 +872,10 @@ int cnid_dbd_find(struct _cnid_db *cdb, const char *name, size_t namelen, void *
     }
 
     LOG(log_debug, logtype_cnid, "cnid_find(\"%s\")", name);
-
     RQST_RESET(&rqst);
     rqst.op = CNID_DBD_OP_SEARCH;
-
     rqst.name = name;
     rqst.namelen = namelen;
-
     rply.name = buffer;
     rply.namelen = buflen;
 
@@ -829,14 +889,19 @@ int cnid_dbd_find(struct _cnid_db *cdb, const char *name, size_t namelen, void *
         count = rply.namelen / sizeof(cnid_t);
         LOG(log_debug, logtype_cnid, "cnid_find: got %d matches", count);
         break;
+
     case CNID_DBD_RES_NOTFOUND:
         count = 0;
         break;
+
     case CNID_DBD_RES_ERR_DB:
         errno = CNID_ERR_DB;
         count = -1;
         break;
+
     default:
+        LOG(log_error, logtype_cnid,
+            "cnid_dbd_find: unexpected result code %d from CNID server", rply.result);
         abort();
     }
 
@@ -866,19 +931,21 @@ int cnid_dbd_update(struct _cnid_db *cdb, cnid_t id, const struct stat *st,
     RQST_RESET(&rqst);
     rqst.op = CNID_DBD_OP_UPDATE;
     rqst.cnid = id;
+
     if (!(cdb->cnid_db_flags & CNID_FLAG_NODEV)) {
         rqst.dev = st->st_dev;
     }
+
     rqst.ino = st->st_ino;
-    rqst.type = S_ISDIR(st->st_mode)?1:0;
+    rqst.type = S_ISDIR(st->st_mode) ? 1 : 0;
     rqst.did = did;
     rqst.name = name;
     rqst.namelen = len;
-
-    LOG(log_debug, logtype_cnid, "cnid_dbd_update: CNID: %u, name: '%s', inode: 0x%llx, type: %d (0=file, 1=dir)",
+    LOG(log_debug, logtype_cnid,
+        "cnid_dbd_update: CNID: %u, name: '%s', inode: 0x%llx, type: %d (0=file, 1=dir)",
         ntohl(id), name, (long long)st->st_ino, rqst.type);
-
     rply.namelen = 0;
+
     if (transmit(db, &rqst, &rply) < 0) {
         errno = CNID_ERR_DB;
         return -1;
@@ -887,12 +954,17 @@ int cnid_dbd_update(struct _cnid_db *cdb, cnid_t id, const struct stat *st,
     switch (rply.result) {
     case CNID_DBD_RES_OK:
         LOG(log_debug, logtype_cnid, "cnid_dbd_update: updated");
+
     case CNID_DBD_RES_NOTFOUND:
         return 0;
+
     case CNID_DBD_RES_ERR_DB:
         errno = CNID_ERR_DB;
         return -1;
+
     default:
+        LOG(log_error, logtype_cnid,
+            "cnid_dbd_update: unexpected result code %d from CNID server", rply.result);
         abort();
     }
 }
@@ -906,7 +978,8 @@ cnid_t cnid_dbd_rebuild_add(struct _cnid_db *cdb, const struct stat *st,
     struct cnid_dbd_rply rply;
     cnid_t id;
 
-    if (!cdb || !(db = cdb->cnid_db_private) || !st || !name || hint == CNID_INVALID) {
+    if (!cdb || !(db = cdb->cnid_db_private) || !st || !name
+            || hint == CNID_INVALID) {
         LOG(log_error, logtype_cnid, "cnid_rebuild_add: Parameter error");
         errno = CNID_ERR_PARAM;
         return CNID_INVALID;
@@ -926,13 +999,13 @@ cnid_t cnid_dbd_rebuild_add(struct _cnid_db *cdb, const struct stat *st,
     }
 
     rqst.ino = st->st_ino;
-    rqst.type = S_ISDIR(st->st_mode)?1:0;
+    rqst.type = S_ISDIR(st->st_mode) ? 1 : 0;
     rqst.did = did;
     rqst.name = name;
     rqst.namelen = len;
     rqst.cnid = hint;
-
-    LOG(log_debug, logtype_cnid, "cnid_dbd_rebuild_add: CNID: %u, name: '%s', inode: 0x%llx, type: %d (0=file, 1=dir), hint: %u",
+    LOG(log_debug, logtype_cnid,
+        "cnid_dbd_rebuild_add: CNID: %u, name: '%s', inode: 0x%llx, type: %d (0=file, 1=dir), hint: %u",
         ntohl(did), name, (long long)st->st_ino, rqst.type, hint);
 
     if (transmit(db, &rqst, &rply) < 0) {
@@ -940,23 +1013,30 @@ cnid_t cnid_dbd_rebuild_add(struct _cnid_db *cdb, const struct stat *st,
         return CNID_INVALID;
     }
 
-    switch(rply.result) {
+    switch (rply.result) {
     case CNID_DBD_RES_OK:
         id = rply.cnid;
         LOG(log_debug, logtype_cnid, "cnid_dbd_rebuild_add: got CNID: %u", ntohl(id));
         break;
+
     case CNID_DBD_RES_ERR_MAX:
         errno = CNID_ERR_MAX;
         id = CNID_INVALID;
         break;
+
     case CNID_DBD_RES_ERR_DB:
     case CNID_DBD_RES_ERR_DUPLCNID:
         errno = CNID_ERR_DB;
         id = CNID_INVALID;
         break;
+
     default:
+        LOG(log_error, logtype_cnid,
+            "cnid_dbd_rebuild_add: unexpected result code %d from CNID server",
+            rply.result);
         abort();
     }
+
     return id;
 }
 
@@ -974,12 +1054,11 @@ int cnid_dbd_delete(struct _cnid_db *cdb, const cnid_t id)
     }
 
     LOG(log_debug, logtype_cnid, "cnid_dbd_delete: delete CNID: %u", ntohl(id));
-
     RQST_RESET(&rqst);
     rqst.op = CNID_DBD_OP_DELETE;
     rqst.cnid = id;
-
     rply.namelen = 0;
+
     if (transmit(db, &rqst, &rply) < 0) {
         errno = CNID_ERR_DB;
         return -1;
@@ -988,12 +1067,17 @@ int cnid_dbd_delete(struct _cnid_db *cdb, const cnid_t id)
     switch (rply.result) {
     case CNID_DBD_RES_OK:
         LOG(log_debug, logtype_cnid, "cnid_dbd_delete: deleted CNID: %u", ntohl(id));
+
     case CNID_DBD_RES_NOTFOUND:
         return 0;
+
     case CNID_DBD_RES_ERR_DB:
         errno = CNID_ERR_DB;
         return -1;
+
     default:
+        LOG(log_error, logtype_cnid,
+            "cnid_dbd_delete: unexpected result code %d from CNID server", rply.result);
         abort();
     }
 }
@@ -1002,7 +1086,7 @@ int cnid_dbd_wipe(struct _cnid_db *cdb)
 {
     CNID_bdb_private *db;
     struct cnid_dbd_rqst rqst;
-    struct cnid_dbd_rply rply;
+    struct cnid_dbd_rply rply = { 0 };
 
     if (!cdb || !(db = cdb->cnid_db_private)) {
         LOG(log_error, logtype_cnid, "cnid_wipe: Parameter error");
@@ -1011,12 +1095,11 @@ int cnid_dbd_wipe(struct _cnid_db *cdb)
     }
 
     LOG(log_debug, logtype_cnid, "cnid_dbd_wipe");
-
     RQST_RESET(&rqst);
     rqst.op = CNID_DBD_OP_WIPE;
     rqst.cnid = 0;
-
     rply.namelen = 0;
+
     if (transmit(db, &rqst, &rply) < 0) {
         errno = CNID_ERR_DB;
         return -1;
@@ -1026,8 +1109,8 @@ int cnid_dbd_wipe(struct _cnid_db *cdb)
         errno = CNID_ERR_DB;
         return -1;
     }
-    LOG(log_debug, logtype_cnid, "cnid_dbd_wipe: ok");
 
+    LOG(log_debug, logtype_cnid, "cnid_dbd_wipe: ok");
     return cnid_dbd_stamp(db);
 }
 
@@ -1038,6 +1121,3 @@ struct _cnid_module cnid_dbd_module = {
     cnid_dbd_open,
     0
 };
-
-#endif /* CNID_DBD */
-
