@@ -1,6 +1,4 @@
 /*
- * $Id: at_var.h,v 1.2 2001-06-29 14:14:47 rufustfirefly Exp $
- *
  * Copyright (c) 1990,1991 Regents of The University of Michigan.
  *
  * All Rights Reserved.  See COPYRIGHT.
@@ -9,7 +7,7 @@
 #ifndef _ATVAR_H
 #define _ATVAR_H 1
 
-/*
+/*!
  * For phase2, we need to keep not only our address on an interface,
  * but also the legal networks on the interface.
  */
@@ -26,18 +24,18 @@ struct at_ifaddr {
 # define aa_dstaddr		aa_ifa.ifa_dstaddr
 #endif /* BSD4_4 */
     int			aa_flags;
-    u_short		aa_firstnet, aa_lastnet;
+    unsigned short		aa_firstnet, aa_lastnet;
     int			aa_probcnt;
     struct at_ifaddr	*aa_next;
 };
 
 #ifdef BSD4_4
 struct at_aliasreq {
-	char	ifra_name[IFNAMSIZ];		/* if name, e.g. "en0" */
-	struct	sockaddr_at ifra_addr;
-	struct	sockaddr_at ifra_broadaddr;
+    char	ifra_name[IFNAMSIZ];		/*!< if name, e.g. "en0" */
+    struct	sockaddr_at ifra_addr;
+    struct	sockaddr_at ifra_broadaddr;
 #define ifra_dstaddr ifra_broadaddr
-	struct	sockaddr_at ifra_mask;
+    struct	sockaddr_at ifra_mask;
 };
 #endif /* BSD4_4 */
 
