@@ -3,7 +3,9 @@
  * All Rights Reserved. See COPYRIGHT.
  */
 
-/*
+/*!
+ * @file
+ * @code
  * <-1byte(8bits) ->
  * +---------------+
  * | 0 | hopc  |len|
@@ -30,6 +32,7 @@
  * +---------------+
  * | Src PORT      |
  * +---------------+
+ * @endcode
  *
  * On Apples, there is also a ddp_type field, after src_port. However,
  * under this unix implementation, user level processes need to be able
@@ -40,12 +43,12 @@
 #ifndef _NETATALK_DDP_H
 #define _NETATALK_DDP_H 1
 
-#include <netatalk/endian.h>
+#include "endian.h"
 
 struct elaphdr {
-    u_char	el_dnode;
-    u_char	el_snode;
-    u_char	el_type;
+    unsigned char	el_dnode;
+    unsigned char	el_snode;
+    unsigned char	el_type;
 };
 
 #define	SZ_ELAPHDR	3
@@ -53,42 +56,42 @@ struct elaphdr {
 #define ELAP_DDPSHORT	0x01
 #define ELAP_DDPEXTEND	0x02
 
-/*
+/*!
  * Extended DDP header. Includes sickness for dealing with arbitrary
  * bitfields on a little-endian arch.
  */
 struct ddpehdr {
     union {
-	struct {
+        struct {
 #if BYTE_ORDER == BIG_ENDIAN
-    unsigned		dub_pad:2;
-    unsigned		dub_hops:4;
-    unsigned		dub_len:10;
-    unsigned		dub_sum:16;
+            unsigned		dub_pad: 2;
+            unsigned		dub_hops: 4;
+            unsigned		dub_len: 10;
+            unsigned		dub_sum: 16;
 #else /* BYTE_ORDER == BIG_ENDIAN */
 #if BYTE_ORDER == LITTLE_ENDIAN
-    unsigned		dub_sum:16;
-    unsigned		dub_len:10;
-    unsigned		dub_hops:4;
-    unsigned		dub_pad:2;
+            unsigned		dub_sum: 16;
+            unsigned		dub_len: 10;
+            unsigned		dub_hops: 4;
+            unsigned		dub_pad: 2;
 #else /* BYTE_ORDER == LITTLE_ENDIAN */
-    OOPS!
+            OOPS!
 #endif /* BYTE_ORDER == LITTLE_ENDIAN */
 #endif /* BYTE_ORDER == BIG_ENDIAN */
-	} du_bits;
-	unsigned	du_bytes;
+        } du_bits;
+        unsigned	du_bytes;
     } deh_u;
 #define deh_pad		deh_u.du_bits.dub_pad
 #define deh_hops	deh_u.du_bits.dub_hops
 #define deh_len		deh_u.du_bits.dub_len
 #define deh_sum		deh_u.du_bits.dub_sum
 #define deh_bytes	deh_u.du_bytes
-    u_short		deh_dnet;
-    u_short		deh_snet;
-    u_char		deh_dnode;
-    u_char		deh_snode;
-    u_char		deh_dport;
-    u_char		deh_sport;
+    unsigned short		deh_dnet;
+    unsigned short		deh_snet;
+    unsigned char		deh_dnode;
+    unsigned char		deh_snode;
+    unsigned char		deh_dport;
+    unsigned char		deh_sport;
 };
 
 #define SZ_DDPEHDR      12
@@ -97,21 +100,21 @@ struct ddpehdr {
 
 struct ddpshdr {
     union {
-	struct {
+        struct {
 #if BYTE_ORDER == BIG_ENDIAN
-    unsigned		dub_pad:6;
-    unsigned		dub_len:10;
-    unsigned		dub_dport:8;
-    unsigned		dub_sport:8;
+            unsigned		dub_pad: 6;
+            unsigned		dub_len: 10;
+            unsigned		dub_dport: 8;
+            unsigned		dub_sport: 8;
 #endif /* BYTE_ORDER == BIG_ENDIAN */
 #if BYTE_ORDER == LITTLE_ENDIAN
-    unsigned		dub_sport:8;
-    unsigned		dub_dport:8;
-    unsigned		dub_len:10;
-    unsigned		dub_pad:6;
+            unsigned		dub_sport: 8;
+            unsigned		dub_dport: 8;
+            unsigned		dub_len: 10;
+            unsigned		dub_pad: 6;
 #endif /* BYTE_ORDER == LITTLE_ENDIAN */
-	} du_bits;
-	unsigned	du_bytes;
+        } du_bits;
+        unsigned	du_bytes;
     } dsh_u;
 #define dsh_pad		dsh_u.du_bits.dub_pad
 #define dsh_len		dsh_u.du_bits.dub_len
