@@ -1,7 +1,8 @@
 /* ----------------------------------------------
 */
-#include "specs.h"
-#include <inttypes.h>
+#include "afpcmd.h"
+#include "afphelper.h"
+#include "testhelper.h"
 
 /* ------------------------- */
 STATIC void test398()
