@@ -1,12 +1,14 @@
 /* ----------------------------------------------
 */
 
-#include "specs.h"
-#include "adoublehelper.h"
-
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <fcntl.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+
+#include "adoublehelper.h"
+#include "afpcmd.h"
+#include "afphelper.h"
+#include "testhelper.h"
 
 static char temp[MAXPATHLEN];
 static char temp1[MAXPATHLEN];
@@ -37,6 +39,7 @@ STATIC void test32()
     FAIL(FPCreateFile(Conn, vol, 0, DIRDID_ROOT, name1))
     FAIL(FPCreateFile(Conn, vol, 0, dir, name1))
 
+    /* FIXME: FPEnumerate* uses my_dsi_data_receive. See afphelper.c:delete_directory_tree() */
     if (FPEnumerate(Conn, vol, dir, "",
                     (1 << FILPBIT_LNAME) | (1 << FILPBIT_FNUM) | (1 << FILPBIT_ATTR) |
                     (1 << FILPBIT_FINFO) |
@@ -154,6 +157,7 @@ STATIC void test33()
     FAIL(FPCreateFile(Conn, vol, 0, DIRDID_ROOT, name1))
     FAIL(FPCreateFile(Conn, vol, 0, dir, name1))
 
+    /* FIXME: FPEnumerate* uses my_dsi_data_receive. See afphelper.c:delete_directory_tree() */
     if (FPEnumerate(Conn, vol, DIRDID_ROOT, name,
                     (1 << FILPBIT_LNAME) | (1 << FILPBIT_FNUM) | (1 << FILPBIT_ATTR) |
                     (1 << FILPBIT_FINFO) |
@@ -271,6 +275,7 @@ STATIC void test42()
         goto fin;
     }
 
+    /* FIXME: FPEnumerate* uses my_dsi_data_receive. See afphelper.c:delete_directory_tree() */
     if (ntohl(AFPERR_NOOBJ) != FPEnumerate(Conn, vol, dir, "",
                                            (1 << FILPBIT_LNAME) | (1 << FILPBIT_FNUM) | (1 << FILPBIT_ATTR) |
                                            (1 << FILPBIT_FINFO) |
@@ -358,7 +363,7 @@ STATIC void test106()
     char *name5 = "t104 file";
     char *name6 = "t104 dir2_1";
     uint16_t vol = VolID;
-    DSI *dsi = &Conn->dsi;
+    const DSI *dsi = &Conn->dsi;
     unsigned int dir1 = 0;
     unsigned int dir2 = 0;
     unsigned int dir3 = 0;
@@ -619,6 +624,7 @@ STATIC void test182()
 
     FAIL(FPCreateFile(Conn, vol, 0, dir, name1))
 
+    /* FIXME: FPEnumerate* uses my_dsi_data_receive. See afphelper.c:delete_directory_tree() */
     if (FPEnumerate(Conn, vol, dir, "",
                     (1 << FILPBIT_LNAME) | (1 << FILPBIT_FNUM) | (1 << FILPBIT_ATTR) |
                     (1 << FILPBIT_FINFO) |
@@ -764,16 +770,15 @@ STATIC void test336()
     char *name = "t336 very long dirname (more than 31 bytes)";
     char *ndir = "t336 dir";
     uint16_t vol = VolID;
-    DSI *dsi;
+    uint16_t vol2;
+    const DSI *dsi = &Conn->dsi;
+    const DSI *dsi2;
     unsigned int  dir;
     uint16_t bitmap = 0;
     int ret;
     int id;
-    uint16_t vol2;
-    DSI *dsi2;
     int  ofs =  3 * sizeof(uint16_t);
     struct afp_filedir_parms filedir;
-    dsi = &Conn->dsi;
     ENTER_TEST
 
     if (!Conn2) {
@@ -906,6 +911,7 @@ STATIC void test340()
     FAIL(FPCreateFile(Conn, vol, 0, DIRDID_ROOT, name1))
     FAIL(FPCreateFile(Conn, vol, 0, dir, name1))
 
+    /* FIXME: FPEnumerate* uses my_dsi_data_receive. See afphelper.c:delete_directory_tree() */
     if (FPEnumerate(Conn, vol, dir, "",
                     (1 << FILPBIT_LNAME) | (1 << FILPBIT_FNUM) | (1 << FILPBIT_ATTR) |
                     (1 << FILPBIT_FINFO) |
@@ -1021,7 +1027,7 @@ STATIC void test420()
     struct afp_filedir_parms filedir;
     int fid = 0;
     uint16_t fork = 0;
-    DSI *dsi = &Conn->dsi;
+    const DSI *dsi = &Conn->dsi;
     ENTER_TEST
 
     if (Path[0] == '\0') {
