@@ -13,8 +13,9 @@
  * GNU General Public License for more details.
  */
 
-/*
- * lantest_io_monitor.c - Linux I/O monitoring for Netatalk performance testing
+/*!
+ * @file
+ * @brief Linux I/O monitoring for Netatalk performance testing
  *
  * Monitors system call I/O statistics for afpd and cnid_dbd processes during tests.
  * Uses /proc_io filesystem (a secondary mount of proc) to track read/write syscalls.
@@ -80,9 +81,10 @@ static int32_t process_proc_entry(const char *pid_dir,
                                   const ProcessFilter *filter,
                                   ProcessList *found);
 static void report_multiple_pids(const ProcessFilter *filter,
-                                 const ProcessList *found);
+                                 const ProcessList *found,
+                                 pid_t highest_pid);
 
-/* Helper: Show warning about /proc_io availability */
+/*! Helper: Show warning about /proc_io availability */
 static void show_proc_io_warning(const char *specific_issue)
 {
     static int32_t warning_shown = 0;
@@ -99,7 +101,7 @@ static void show_proc_io_warning(const char *specific_issue)
     }
 }
 
-/* Helper: Check if /proc_io is available and show warning if not */
+/*! Helper: Check if /proc_io is available and show warning if not */
 int32_t check_proc_io_availability(void)
 {
     struct stat st;
@@ -149,7 +151,7 @@ int32_t check_proc_io_availability(void)
     return 1;
 }
 
-/* Helper: Initialize process filter configuration */
+/*! Helper: Initialize process filter configuration */
 static int32_t init_process_filter(ProcessFilter *filter,
                                    const char *process_name,
                                    const char *username, int32_t filter_by_cmdline)
@@ -171,17 +173,23 @@ static int32_t init_process_filter(ProcessFilter *filter,
         }
 
         filter->target_uid = pwd->pw_uid;
-        fprintf(stdout, "Looking for %s processes owned by user '%s' (UID: %u)\n",
-                process_name, username, filter->target_uid);
+
+        if (Debug) {
+            fprintf(stderr,
+                    "DEBUG: Looking for %s processes owned by user '%s' (UID: %u)\n",
+                    process_name, username, filter->target_uid);
+        }
     } else {
-        fprintf(stdout, "Looking for %s processes with -u %s in command line\n",
-                process_name, username);
+        if (Debug) {
+            fprintf(stderr, "DEBUG: Looking for %s processes with -u %s in command line\n",
+                    process_name, username);
+        }
     }
 
     return 0;
 }
 
-/* Helper: Check if process name matches target_name */
+/*! Helper: Check if process name matches target_name */
 static int32_t check_process_name_match(const char *pid_dir,
                                         const char *target_name)
 {
@@ -214,7 +222,7 @@ static int32_t check_process_name_match(const char *pid_dir,
     return matches;
 }
 
-/* Helper: Check if process matches cmdline filter (-u username) */
+/*! Helper: Check if process matches cmdline filter (-u username) */
 static int32_t check_cmdline_filter(const char *pid_dir, const char *username)
 {
     char cmdline_path[PATH_BUFFER_SIZE];
@@ -272,7 +280,7 @@ static int32_t check_cmdline_filter(const char *pid_dir, const char *username)
     return 0;
 }
 
-/* Helper: Check if process matches UID filter (ownership) */
+/*! Helper: Check if process matches UID filter (ownership) */
 static int32_t check_uid_filter(const char *pid_dir, uid_t target_uid)
 {
     char status_path[PATH_BUFFER_SIZE];
@@ -305,7 +313,7 @@ static int32_t check_uid_filter(const char *pid_dir, uid_t target_uid)
     return matches;
 }
 
-/* Helper: Process a single /proc directory entry */
+/*! Helper: Process a single /proc directory entry */
 static int32_t process_proc_entry(const char *pid_dir,
                                   const ProcessFilter *filter,
                                   ProcessList *found)
@@ -342,9 +350,10 @@ static int32_t process_proc_entry(const char *pid_dir,
     return 0;
 }
 
-/* Helper: Report multiple PIDs found */
+/*! Helper: Report multiple PIDs found and get highest PID */
 static void report_multiple_pids(const ProcessFilter *filter,
-                                 const ProcessList *found)
+                                 const ProcessList *found,
+                                 pid_t highest_pid)
 {
     if (filter->filter_by_cmdline) {
         fprintf(stderr, "Warning: Multiple %s processes with -u %s found (",
@@ -362,10 +371,10 @@ static void report_multiple_pids(const ProcessFilter *filter,
         }
     }
 
-    fprintf(stderr, "), using first: %d\n", found->pids[0]);
+    fprintf(stderr, "), using highest: %d\n", highest_pid);
 }
 
-/* Main Netatalk process find function for IO monitoring */
+/*! Main Netatalk process find function for IO monitoring */
 pid_t find_process_pid(const char *process_name, const char *username,
                        int32_t filter_by_cmdline)
 {
@@ -431,14 +440,24 @@ pid_t find_process_pid(const char *process_name, const char *username,
         return 0;
     }
 
-    if (found.count > 1) {
-        report_multiple_pids(&filter, &found);
+    /* Find the highest PID */
+    pid_t highest_pid = found.pids[0];
+
+    for (int32_t i = 1; i < found.count; i++) {
+        if (found.pids[i] > highest_pid) {
+            highest_pid = found.pids[i];
+        }
     }
 
-    return found.pids[0];
+    if (found.count > 1) {
+        report_multiple_pids(&filter, &found, highest_pid);
+    }
+
+    return highest_pid;
 }
 
-/* Read IO statistics from /proc_io/<pid>/io file.
+/*! @brief Read IO statistics from /proc_io/<pid>/io file.
+ *
  * syscr: cumulative count of read system calls (read(), pread(), readv(), etc.)
  * syscw: cumulative count of write system calls (write(), pwrite(), writev(), etc.) */
 static int32_t read_proc_io(pid_t pid, uint64_t *read_ops,
@@ -480,7 +499,7 @@ static int32_t read_proc_io(pid_t pid, uint64_t *read_ops,
     return (found_read && found_write) ? 0 : -1;
 }
 
-/* Capture IO values - consolidated function for start and stop */
+/*! Capture IO values - consolidated function for start and stop */
 void capture_io_values(int32_t is_start)
 {
     if (!io_monitoring_enabled) {
@@ -508,7 +527,7 @@ void capture_io_values(int32_t is_start)
     }
 }
 
-/* Get IO delta between stored cumulative counts - consolidated for read and write */
+/*! Get IO delta between stored cumulative counts - consolidated for read and write */
 uint64_t iodiff_io(pid_t pid, int32_t is_write)
 {
     uint64_t start_val, end_val;
@@ -530,7 +549,7 @@ uint64_t iodiff_io(pid_t pid, int32_t is_write)
     return (end_val > start_val) ? end_val - start_val : 0;
 }
 
-/* Safe PID string parsing helper */
+/*! Safe PID string parsing helper */
 static pid_t safe_parse_pid(const char *pid_str)
 {
     char *endptr;
@@ -557,7 +576,7 @@ static pid_t safe_parse_pid(const char *pid_str)
     return (pid_t)val;
 }
 
-/* Initialize IO monitoring by checking proc filesystem and finding required processes */
+/*! Initialize IO monitoring by checking proc filesystem and finding required processes */
 void init_io_monitoring(const char *username)
 {
     /* Check if /proc_io is available */
@@ -581,7 +600,8 @@ void init_io_monitoring(const char *username)
                                     1);  /* Filter -u argument */
 
     if (cnid_dbd_pid > 0) {
-        fprintf(stdout, "Found cnid_dbd process: PID %d\n", cnid_dbd_pid);
+        fprintf(stdout, "Found cnid_dbd process for user '%s': PID %d\n", username,
+                cnid_dbd_pid);
     } else {
         fprintf(stdout, "cnid_dbd not found (optional), continuing...\n");
         cnid_dbd_pid = 0;  /* Explicitly set to 0 */
@@ -611,7 +631,8 @@ void init_io_monitoring(const char *username)
     }
 
     if (afpd_pid > 0) {
-        fprintf(stdout, "Found privilege-dropped afpd process: PID %d\n", afpd_pid);
+        fprintf(stdout, "Found privilege-dropped afpd process for user '%s': PID %d\n",
+                username, afpd_pid);
     } else {
         fprintf(stderr, "Error: afpd process not found (mandatory)\n");
     }
